# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['nautobot_plugin_chatops_grafana',
 'nautobot_plugin_chatops_grafana.api',
 'nautobot_plugin_chatops_grafana.api.views',
 'nautobot_plugin_chatops_grafana.diffsync',
 'nautobot_plugin_chatops_grafana.management.commands',
 'nautobot_plugin_chatops_grafana.migrations',
 'nautobot_plugin_chatops_grafana.tests']

package_data = \
{'': ['*'],
 'nautobot_plugin_chatops_grafana': ['schema/schemas/*',
                                     'static/grafana/*',
                                     'templates/nautobot_plugin_chatops_grafana/*']}

install_requires = \
['diffsync>=1.3.0,<2.0.0',
 'isodate>=0.6.0,<0.7.0',
 'nautobot-chatops>=1.3.1,<2.0.0',
 'pydantic>=1.8.2,<2.0.0',
 'schema-enforcer>=1.1.1,<2.0.0']

extras_require = \
{':extra == "nautobot"': ['nautobot>=1.0.0,<2.0.0']}

entry_points = \
{'nautobot.workers': ['grafana = '
                      'nautobot_plugin_chatops_grafana.worker:grafana']}

setup_kwargs = {
    'name': 'nautobot-chatops-grafana',
    'version': '1.0.1',
    'description': 'Nautobot Plugin Chatops Grafana',
    'long_description': '# Grafana ChatOps \n\nThe Grafana Chatops plugin is a [Nautobot](https://github.com/nautobot/nautobot) extension used with \nthe [Nautobot ChatOps](https://github.com/nautobot/nautobot-plugin-chatops/)\nbase framework to provide all the operational graphs provided by Grafana delivered via chat clients.\n\n## Documentation\n * [Installation Guide](docs/installation.md)\n * [Getting Started](docs/getting_started.md)\n * [Advanced Usage Guide](docs/advanced_usage.md)\n * [FAQ](docs/faq.md)\n * [Contributing](docs/contributing.md)\n * [Code of Conduct](docs/code_of_conduct.md)\n\n\n## Usage\n\nFor basic usage and getting your first set of Grafana commands added to your chat client, see\nthe [Getting Started Guide](docs/getting_started.md).\n\nTo dive deeper into the Grafana configuration and variables within dashboards, see our \n[Advanced Usage Guide](docs/advanced_usage.md)\n\n## Contributing\n\nThank you for your interest in helping to improve the Nautobot Grafana Plugin! \nPlease refer to the [contributing](docs/contributing.md) guidelines for details.\n\n### Project Documentation\n\nProject documentation is generated by [mkdocs](https://www.mkdocs.org/) from the documentation located in the docs folder.  \nYou can configure [readthedocs.io](https://readthedocs.io/) to point at this folder in your repo.  \nFor development purposes a `docker-compose.docs.yml` is also included. \n A container hosting the docs will be started using the invoke commands on [http://localhost:8001](http://localhost:8001), \n as changes are saved the docs will be automatically reloaded.\n\n## Questions\n\nFor any questions or comments, please check the [FAQ](docs/faq.md) first and feel free to swing by \nthe [Network to Code slack channel](https://networktocode.slack.com/) (channel #networktocode).\nSign up [here](http://slack.networktocode.com/)\n\n## Screenshots\n\n* Get Top-Host *Bar Gauge* specifying the `last 12 months`:\n![Top Hosts P12M](docs/img/ss_top_host_timespan_P12M.png)\n\n* Get Successful Automation Jobs *Graph* specifying the `last 12 months` and `light` theme:\n![Top Hosts P12M](docs/img/ss_successful_jobs_lighttheme.png)\n\n* Get Automation Jobs Run *Stat* chart specifying the `last 12 months`:\n![Top Hosts P12M](docs/img/ss_jobs_run_P12M.png)\n\n* Get Automation Jobs Run *Stat* chart specifying the `last 12 months` using a custom variable of `Playbook`:\n![Top Hosts P12M](docs/img/ss_jobs_run_P12M_w_Playbook.png)\n\n* Get Top-Host *Bar Gauge* specifying the `last 12 months` with a `Device` and `Site` variable set, prompting in chat:\n![Top Hosts P12M](docs/img/ss_top_host_variable_prompt.png)\n',
    'author': 'Network to Code, LLC',
    'author_email': 'opensource@networktocode.com',
    'maintainer': None,
    'maintainer_email': None,
    'url': 'https://github.com/nautobot/nautobot-plugin-chatops-grafana',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'extras_require': extras_require,
    'entry_points': entry_points,
    'python_requires': '>=3.7,<4.0',
}


setup(**setup_kwargs)
